==> 2023.02.25.tar.gz: dooble-2023.02.25/Source/dooble_main_window.h <==
/*
** Copyright (c) 2008 - present, Alexis Megas.
** All rights reserved.
**
** Redistribution and use in source and binary forms, with or without
** modification, are permitted provided that the following conditions
** are met:
** 1. Redistributions of source code must retain the above copyright
**    notice, this list of conditions and the following disclaimer.
** 2. Redistributions in binary form must reproduce the above copyright
**    notice, this list of conditions and the following disclaimer in the
**    documentation and/or other materials provided with the distribution.
** 3. The name of the author may not be used to endorse or promote products
**    derived from Dooble without specific prior written permission.
**
** DOOBLE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
** IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
** OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
** IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
** INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
** NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
** DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
** THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
** (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
** DOOBLE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

#ifndef dooble_main_window_h
#define dooble_main_window_h

#include <QMainWindow>
#include <QShortcut>

class dooble_main_window: public QMainWindow
{
  Q_OBJECT

 public:
  dooble_main_window(QWidget *parent):QMainWindow(parent)
  {
    m_control_w = new QShortcut
      (QKeySequence(tr("Ctrl+W")), this, SLOT(close(void)));
    m_control_w->setEnabled(false);
  }

  dooble_main_window(void):dooble_main_window(nullptr)
  {
  }

  virtual ~dooble_main_window()
  {
  }

  void enable_control_w_shortcut(const bool state)
  {
    m_control_w->setEnabled(state);
  }

 protected:
  QShortcut *m_control_w;
};

#endif

==> 2024.01.25.tar.gz: dooble-2024.01.25/Source/dooble_main_window.h <==
/*
** Copyright (c) 2008 - present, Alexis Megas.
** All rights reserved.
**
** Redistribution and use in source and binary forms, with or without
** modification, are permitted provided that the following conditions
** are met:
** 1. Redistributions of source code must retain the above copyright
**    notice, this list of conditions and the following disclaimer.
** 2. Redistributions in binary form must reproduce the above copyright
**    notice, this list of conditions and the following disclaimer in the
**    documentation and/or other materials provided with the distribution.
** 3. The name of the author may not be used to endorse or promote products
**    derived from Dooble without specific prior written permission.
**
** DOOBLE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
** IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
** OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
** IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
** INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
** NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
** DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
** THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
** (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
** DOOBLE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

#ifndef dooble_main_window_h
#define dooble_main_window_h

#include <QMainWindow>
#include <QShortcut>

class dooble_main_window: public QMainWindow
{
  Q_OBJECT

 public:
  dooble_main_window(QWidget *parent):QMainWindow(parent)
  {
    m_control_w = new QShortcut
      (QKeySequence(tr("Ctrl+W")), this, SLOT(close(void)));
    m_control_w->setEnabled(false);
  }

  dooble_main_window(void):dooble_main_window(nullptr)
  {
  }

  virtual ~dooble_main_window()
  {
  }

  void enable_control_w_shortcut(bool state)
  {
    m_control_w->setEnabled(state);
  }

 protected:
  QShortcut *m_control_w;
};

#endif
